==> servicecatalog-model-6.6.1-sources.jar: io/fabric8/servicecatalog/api/model/CatalogRestrictionsFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface CatalogRestrictionsFluent<A extends CatalogRestrictionsFluent<A>> extends Fluent<A>{
  public A addToServiceClass(Integer index,String item);
  public A setToServiceClass(Integer index,String item);
  public A addToServiceClass(java.lang.String... items);
  public A addAllToServiceClass(Collection<String> items);
  public A removeFromServiceClass(java.lang.String... items);
  public A removeAllFromServiceClass(Collection<String> items);
  public List<String> getServiceClass();
  public String getServiceClass(Integer index);
  public String getFirstServiceClass();
  public String getLastServiceClass();
  public String getMatchingServiceClass(Predicate<String> predicate);
  public Boolean hasMatchingServiceClass(Predicate<String> predicate);
  public A withServiceClass(List<String> serviceClass);
  public A withServiceClass(java.lang.String... serviceClass);
  public Boolean hasServiceClass();
  public A addToServicePlan(Integer index,String item);
  public A setToServicePlan(Integer index,String item);
  public A addToServicePlan(java.lang.String... items);
  public A addAllToServicePlan(Collection<String> items);
  public A removeFromServicePlan(java.lang.String... items);
  public A removeAllFromServicePlan(Collection<String> items);
  public List<String> getServicePlan();
  public String getServicePlan(Integer index);
  public String getFirstServicePlan();
  public String getLastServicePlan();
  public String getMatchingServicePlan(Predicate<String> predicate);
  public Boolean hasMatchingServicePlan(Predicate<String> predicate);
  public A withServicePlan(List<String> servicePlan);
  public A withServicePlan(java.lang.String... servicePlan);
  public Boolean hasServicePlan();
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/CatalogRestrictionsFluent.java <==
package io.fabric8.servicecatalog.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface CatalogRestrictionsFluent<A extends CatalogRestrictionsFluent<A>> extends Fluent<A>{
  public A addToServiceClass(int index,String item);
  public A setToServiceClass(int index,String item);
  public A addToServiceClass(java.lang.String... items);
  public A addAllToServiceClass(Collection<String> items);
  public A removeFromServiceClass(java.lang.String... items);
  public A removeAllFromServiceClass(Collection<String> items);
  public List<String> getServiceClass();
  public String getServiceClass(int index);
  public String getFirstServiceClass();
  public String getLastServiceClass();
  public String getMatchingServiceClass(Predicate<String> predicate);
  public Boolean hasMatchingServiceClass(Predicate<String> predicate);
  public A withServiceClass(List<String> serviceClass);
  public A withServiceClass(java.lang.String... serviceClass);
  public Boolean hasServiceClass();
  public A addToServicePlan(int index,String item);
  public A setToServicePlan(int index,String item);
  public A addToServicePlan(java.lang.String... items);
  public A addAllToServicePlan(Collection<String> items);
  public A removeFromServicePlan(java.lang.String... items);
  public A removeAllFromServicePlan(Collection<String> items);
  public List<String> getServicePlan();
  public String getServicePlan(int index);
  public String getFirstServicePlan();
  public String getLastServicePlan();
  public String getMatchingServicePlan(Predicate<String> predicate);
  public Boolean hasMatchingServicePlan(Predicate<String> predicate);
  public A withServicePlan(List<String> servicePlan);
  public A withServicePlan(java.lang.String... servicePlan);
  public Boolean hasServicePlan();
  
}
